==> org-lsst-ccs-ui-3.4.6-sources.jar: org/lsst/ccs/gconsole/base/filter/States.java <==
package org.lsst.ccs.gconsole.base.filter;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import org.lsst.ccs.gconsole.annotations.ConsoleLookup;
import org.lsst.ccs.gconsole.annotations.services.persist.Create;
import org.lsst.ccs.gconsole.annotations.services.persist.Par;

/**
 * Filter that selects subsystem state channels.
 *
 * @author onoprien
 */
@ConsoleLookup(id = "org.lsst.ccs.gconsole.agent.AgentChannelsFilter",
        name = "States",
        path = "Built-In/States",
        description = "Channels filter that selects subsystem state channels.<p>"
                + "<b>Optional parameters:</b>"
                + "<dl>"
                + "<dt>agents</dt><dd>Comma-separated list of subsystems accepted by this filter.</dd>"
                + "</dl>")
public class States extends AbstractChannelsFilter {

// -- Fields : -----------------------------------------------------------------
    
    private final String name;
    private final List<String> agents;

// -- Life cycle : -------------------------------------------------------------
    
    @Create(category = "AgentChannelsFilter",
            name = "States",
            path = "Built-In/States",
            description = "Channels filter that selects subsystem state channels.")
    public States(
            @Par(def = "States", desc = "Filter name.") String name,
            @Par(def = Par.NULL, desc = "List of subsystems accepted by this filter. If null, all subsystems are accepted.") List<String> agents)
    {
        this.name = name;
        this.agents = agents == null ? null : new ArrayList<>(agents);
    }
    
// -- Implementing filter : ----------------------------------------------------

    @Override
    public List<String> getDisplayPaths(String originPath) {
        String displayPath = originPath.replaceFirst("/state/", "/");
        return Collections.singletonList(displayPath);
    }

    @Override
    public String getOriginPath(String displayPath) {
        return displayPath.replaceFirst("/", "/state/");
    }

    @Override
    public List<String> getOriginChannels() {
        return Collections.singletonList("/state/");
    }

    @Override
    public List<String> getAgents() {
        return agents == null ? null : Collections.unmodifiableList(agents);
    }

    @Override
    public String getName() {
        return name;
    }

}

==> org-lsst-ccs-ui-3.7.1-sources.jar: org/lsst/ccs/gconsole/base/filter/States.java <==
package org.lsst.ccs.gconsole.base.filter;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collections;
import java.util.List;
import org.lsst.ccs.gconsole.annotations.ConsoleLookup;
import org.lsst.ccs.gconsole.annotations.services.persist.Create;
import org.lsst.ccs.gconsole.annotations.services.persist.Par;
import org.lsst.ccs.gconsole.services.aggregator.AgentChannel;

/**
 * Filter that selects subsystem state channels.
 *
 * @author onoprien
 */
//@ConsoleLookup(id = "org.lsst.ccs.gconsole.agent.AgentChannelsFilter",
//        name = "States",
//        path = "Built-In/States",
//        description = "Channels filter that selects subsystem state channels.<p>"
//                + "<b>Optional parameters:</b>"
//                + "<dl>"
//                + "<dt>agents</dt><dd>Comma-separated list of subsystems accepted by this filter.</dd>"
//                + "</dl>")
public class States extends AbstractChannelsFilter {

// -- Fields : -----------------------------------------------------------------
    
    private final String name;
    private final List<String> agents;

// -- Life cycle : -------------------------------------------------------------
    
    @Create(category = "AgentChannelsFilter",
            name = "States",
            path = "Built-In/States",
            description = "Channels filter that selects subsystem state channels.")
    public States(
            @Par(def = "States", desc = "Filter name.") String name,
            @Par(def = Par.NULL, desc = "List of subsystems accepted by this filter. If null, all subsystems are accepted.") List<String> agents)
    {
        this.name = name;
        this.agents = agents == null ? null : new ArrayList<>(agents);
    }
    
// -- Implementing filter : ----------------------------------------------------

    @Override
    public List<String> getDisplayPaths(String originPath) {
        String displayPath = originPath.replaceFirst("/state/", "/");
        return Collections.singletonList(displayPath);
    }

    @Override
    public String getOriginPath(String displayPath) {
        return displayPath.replaceFirst("/", "/state/");
    }

    @Override
    public List<String> getOriginChannels() {
        return Collections.singletonList("/state/");
    }

    @Override
    public List<String> getAgents() {
        return agents == null ? null : Collections.unmodifiableList(agents);
    }

    @Override
    public String getName() {
        return name;
    }

}
